// Lights Examples 
// By Jonas Vorwerk http://jonasvorwerk.nl 2017

#include "FastLED.h"          // include fastled library, check http://fastled.io

#define DATA_PIN 11           // Yellow wire into port 11
#define CLOCK_PIN 13          // Green wire into port 13

#define NUM_LEDS 51           // How many leds in your strip?
#define BRIGHTNESS 64         // Total max brightness of ll your leds
#define FRAMES_PER_SECOND 30  // frames per second

int hue = 0;
int sat = 0;
int val = 0;

int current_led = 0;          // counter for all leds, starting at the first, nimber 0

CRGB leds[NUM_LEDS];          // Define the array of leds

void setup() { 
  //this is the setup for this P9813 led. Look into the fastled blink example for more led types
  FastLED.addLeds<P9813, DATA_PIN, CLOCK_PIN, RGB>(leds, NUM_LEDS);
  //FastLED.addLeds<WS2812, DATA_PIN, GRB>(leds, NUM_LEDS);
  FastLED.setBrightness(BRIGHTNESS);
  FastLED.clear();
}

void loop() {  

  loop_leds();          // call the function loop_leds
  //one_color();        // .. one_color
  //randomcolor();       // .. random color 
  //sinelon();
  //color_some_leds();
  //blink_led(0);
  
  FastLED.show();                           // show all led colors
  FastLED.delay(1000/FRAMES_PER_SECOND);    // delay 
  
}


void color_some_leds(){
  leds[0] = CHSV(0, 255, 255);  // set led number 0 to HSV = HUE SATURATION VALUE/BRIGHTNESS
  leds[1] = CRGB::Red;          // set led number 1 to RGB color: Red
  leds[2] = CRGB::Green;
  leds[3] = CRGB::Blue;
}


void blink_led(int led) { 
  // Turn the LED on, then pause
  leds[led] = CRGB::Red;
  FastLED.show();
  delay(500);
  // Now turn the LED off, then pause
  leds[led] = CRGB::Black;
  FastLED.show();
  delay(500);
}

// set all pixels to a random color
void randomcolor(){
  hue = random(255);
  for (int i = 0 ; i < NUM_LEDS ; i++) {  
    leds[i] = CHSV(hue, 255, 255);
  } 
}

// loop all leds
void loop_leds(){
  fade_black();                             //fade out for leds
  leds[current_led] = CHSV(20, 255, 255);   // set the color for the current_led 

  if(current_led < NUM_LEDS) {              // if the current_led is smaller than the total amount of leds
    current_led++;                          //    increase the current_led by one (+1)
  } else {                                  // else
    current_led = 0;                        //    set current_led to the first led again
  }
}

// fade out to black
void fade_black(){
  for (int i = 0 ; i < NUM_LEDS ; i++) { 
    leds[i].fadeToBlackBy(20);
  }
}

// set all pixels to one color
void one_color(){
  for (int i = 0 ; i < NUM_LEDS ; i++) {  
    leds[i] = CHSV(20, 255, 255);
  } 
}

// set all pixels to a random color
void random_color(){
  hue = random(255);
  for (int i = 0 ; i < NUM_LEDS ; i++) {  
    leds[i] = CHSV(hue, 255, 255);
  } 
}

// a colored dot sweeping back and forth, with fading trails 
// code from demoreel100
void sinelon(){
  fadeToBlackBy( leds, NUM_LEDS, 20);
  int pos = beatsin16(13,0,NUM_LEDS);
  leds[pos] += CHSV( hue, 255, 192);
}
